@@ -9,7 +9,7 @@
 
 
 
-performance <- function(FUN = mean, units = "days", flow_time = c("inter_start_time","idle_time")) {
+performance <- function(FUN = mean, units = "days", flow_time = c("idle_time","inter_start_time")) {
 	flow_time <- match.arg(flow_time)
 	attr(FUN, "flow_time") <- flow_time
 	attr(FUN, "perspective") <- "performance"
